# files/compressed/lz -- lintian check script -*- perl -*-

# Copyright © 2020 Chris Lamb
# Copyright © 2020 Felix Lechner
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, you can find it on the World Wide
# Web at http://www.gnu.org/copyleft/gpl.html, or write to the Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
# MA 02110-1301, USA.

package Lintian::files::compressed::lz;

use v5.20;
use warnings;
use utf8;

use Lintian::Util qw(check_path);
use Lintian::IPC::Run3 qw(safe_qx);

use Moo;
use Carp qw(croak);
use namespace::clean;

with 'Lintian::Check';

sub visit_installed_files {
    my ($self, $file) = @_;

    return
      unless $file->is_file;

    if ($file->name =~ /\.lz$/si) {

        safe_qx(get_lzip_helper(), '--test', $file->unpacked_path);

        $self->tag('broken-lz', $file->name)
          if $?;
    }

    return;
}

sub get_lzip_helper {

    foreach my $helper (qw(lzip clzip)) {
        return $helper if check_path($helper);
    }

    croak "Could not find any .lz helper in \$PATH";
}

1;

# Local Variables:
# indent-tabs-mode: nil
# cperl-indent-level: 4
# End:
# vim: syntax=perl sw=4 sts=4 sr et
